"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.account_budget_proposal_type_pb2
import google.ads.google_ads.v6.proto.enums.account_budget_status_pb2
import google.ads.google_ads.v6.proto.enums.spending_limit_type_pb2
import google.ads.google_ads.v6.proto.enums.time_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AccountBudget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class PendingAccountBudgetProposal(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        ACCOUNT_BUDGET_PROPOSAL_FIELD_NUMBER: builtins.int
        PROPOSAL_TYPE_FIELD_NUMBER: builtins.int
        NAME_FIELD_NUMBER: builtins.int
        START_DATE_TIME_FIELD_NUMBER: builtins.int
        PURCHASE_ORDER_NUMBER_FIELD_NUMBER: builtins.int
        NOTES_FIELD_NUMBER: builtins.int
        CREATION_DATE_TIME_FIELD_NUMBER: builtins.int
        END_DATE_TIME_FIELD_NUMBER: builtins.int
        END_TIME_TYPE_FIELD_NUMBER: builtins.int
        SPENDING_LIMIT_MICROS_FIELD_NUMBER: builtins.int
        SPENDING_LIMIT_TYPE_FIELD_NUMBER: builtins.int
        account_budget_proposal: typing.Text = ...
        proposal_type: google.ads.google_ads.v6.proto.enums.account_budget_proposal_type_pb2.AccountBudgetProposalTypeEnum.AccountBudgetProposalType.V = (
            ...
        )
        name: typing.Text = ...
        start_date_time: typing.Text = ...
        purchase_order_number: typing.Text = ...
        notes: typing.Text = ...
        creation_date_time: typing.Text = ...
        end_date_time: typing.Text = ...
        end_time_type: google.ads.google_ads.v6.proto.enums.time_type_pb2.TimeTypeEnum.TimeType.V = (
            ...
        )
        spending_limit_micros: builtins.int = ...
        spending_limit_type: google.ads.google_ads.v6.proto.enums.spending_limit_type_pb2.SpendingLimitTypeEnum.SpendingLimitType.V = (
            ...
        )
        def __init__(
            self,
            *,
            account_budget_proposal: typing.Text = ...,
            proposal_type: google.ads.google_ads.v6.proto.enums.account_budget_proposal_type_pb2.AccountBudgetProposalTypeEnum.AccountBudgetProposalType.V = ...,
            name: typing.Text = ...,
            start_date_time: typing.Text = ...,
            purchase_order_number: typing.Text = ...,
            notes: typing.Text = ...,
            creation_date_time: typing.Text = ...,
            end_date_time: typing.Text = ...,
            end_time_type: google.ads.google_ads.v6.proto.enums.time_type_pb2.TimeTypeEnum.TimeType.V = ...,
            spending_limit_micros: builtins.int = ...,
            spending_limit_type: google.ads.google_ads.v6.proto.enums.spending_limit_type_pb2.SpendingLimitTypeEnum.SpendingLimitType.V = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "_account_budget_proposal",
                b"_account_budget_proposal",
                "_creation_date_time",
                b"_creation_date_time",
                "_name",
                b"_name",
                "_notes",
                b"_notes",
                "_purchase_order_number",
                b"_purchase_order_number",
                "_start_date_time",
                b"_start_date_time",
                "account_budget_proposal",
                b"account_budget_proposal",
                "creation_date_time",
                b"creation_date_time",
                "end_date_time",
                b"end_date_time",
                "end_time",
                b"end_time",
                "end_time_type",
                b"end_time_type",
                "name",
                b"name",
                "notes",
                b"notes",
                "purchase_order_number",
                b"purchase_order_number",
                "spending_limit",
                b"spending_limit",
                "spending_limit_micros",
                b"spending_limit_micros",
                "spending_limit_type",
                b"spending_limit_type",
                "start_date_time",
                b"start_date_time",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "_account_budget_proposal",
                b"_account_budget_proposal",
                "_creation_date_time",
                b"_creation_date_time",
                "_name",
                b"_name",
                "_notes",
                b"_notes",
                "_purchase_order_number",
                b"_purchase_order_number",
                "_start_date_time",
                b"_start_date_time",
                "account_budget_proposal",
                b"account_budget_proposal",
                "creation_date_time",
                b"creation_date_time",
                "end_date_time",
                b"end_date_time",
                "end_time",
                b"end_time",
                "end_time_type",
                b"end_time_type",
                "name",
                b"name",
                "notes",
                b"notes",
                "proposal_type",
                b"proposal_type",
                "purchase_order_number",
                b"purchase_order_number",
                "spending_limit",
                b"spending_limit",
                "spending_limit_micros",
                b"spending_limit_micros",
                "spending_limit_type",
                b"spending_limit_type",
                "start_date_time",
                b"start_date_time",
            ],
        ) -> None: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_account_budget_proposal", b"_account_budget_proposal"
            ],
        ) -> typing_extensions.Literal["account_budget_proposal"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_creation_date_time", b"_creation_date_time"
            ],
        ) -> typing_extensions.Literal["creation_date_time"]: ...
        @typing.overload
        def WhichOneof(
            self, oneof_group: typing_extensions.Literal["_name", b"_name"]
        ) -> typing_extensions.Literal["name"]: ...
        @typing.overload
        def WhichOneof(
            self, oneof_group: typing_extensions.Literal["_notes", b"_notes"]
        ) -> typing_extensions.Literal["notes"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_purchase_order_number", b"_purchase_order_number"
            ],
        ) -> typing_extensions.Literal["purchase_order_number"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_start_date_time", b"_start_date_time"
            ],
        ) -> typing_extensions.Literal["start_date_time"]: ...
        @typing.overload
        def WhichOneof(
            self, oneof_group: typing_extensions.Literal["end_time", b"end_time"]
        ) -> typing_extensions.Literal["end_date_time", "end_time_type"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal["spending_limit", b"spending_limit"],
        ) -> typing_extensions.Literal[
            "spending_limit_micros", "spending_limit_type"
        ]: ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    BILLING_SETUP_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROPOSED_START_DATE_TIME_FIELD_NUMBER: builtins.int
    APPROVED_START_DATE_TIME_FIELD_NUMBER: builtins.int
    TOTAL_ADJUSTMENTS_MICROS_FIELD_NUMBER: builtins.int
    AMOUNT_SERVED_MICROS_FIELD_NUMBER: builtins.int
    PURCHASE_ORDER_NUMBER_FIELD_NUMBER: builtins.int
    NOTES_FIELD_NUMBER: builtins.int
    PENDING_PROPOSAL_FIELD_NUMBER: builtins.int
    PROPOSED_END_DATE_TIME_FIELD_NUMBER: builtins.int
    PROPOSED_END_TIME_TYPE_FIELD_NUMBER: builtins.int
    APPROVED_END_DATE_TIME_FIELD_NUMBER: builtins.int
    APPROVED_END_TIME_TYPE_FIELD_NUMBER: builtins.int
    PROPOSED_SPENDING_LIMIT_MICROS_FIELD_NUMBER: builtins.int
    PROPOSED_SPENDING_LIMIT_TYPE_FIELD_NUMBER: builtins.int
    APPROVED_SPENDING_LIMIT_MICROS_FIELD_NUMBER: builtins.int
    APPROVED_SPENDING_LIMIT_TYPE_FIELD_NUMBER: builtins.int
    ADJUSTED_SPENDING_LIMIT_MICROS_FIELD_NUMBER: builtins.int
    ADJUSTED_SPENDING_LIMIT_TYPE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: builtins.int = ...
    billing_setup: typing.Text = ...
    status: google.ads.google_ads.v6.proto.enums.account_budget_status_pb2.AccountBudgetStatusEnum.AccountBudgetStatus.V = (
        ...
    )
    name: typing.Text = ...
    proposed_start_date_time: typing.Text = ...
    approved_start_date_time: typing.Text = ...
    total_adjustments_micros: builtins.int = ...
    amount_served_micros: builtins.int = ...
    purchase_order_number: typing.Text = ...
    notes: typing.Text = ...
    proposed_end_date_time: typing.Text = ...
    proposed_end_time_type: google.ads.google_ads.v6.proto.enums.time_type_pb2.TimeTypeEnum.TimeType.V = (
        ...
    )
    approved_end_date_time: typing.Text = ...
    approved_end_time_type: google.ads.google_ads.v6.proto.enums.time_type_pb2.TimeTypeEnum.TimeType.V = (
        ...
    )
    proposed_spending_limit_micros: builtins.int = ...
    proposed_spending_limit_type: google.ads.google_ads.v6.proto.enums.spending_limit_type_pb2.SpendingLimitTypeEnum.SpendingLimitType.V = (
        ...
    )
    approved_spending_limit_micros: builtins.int = ...
    approved_spending_limit_type: google.ads.google_ads.v6.proto.enums.spending_limit_type_pb2.SpendingLimitTypeEnum.SpendingLimitType.V = (
        ...
    )
    adjusted_spending_limit_micros: builtins.int = ...
    adjusted_spending_limit_type: google.ads.google_ads.v6.proto.enums.spending_limit_type_pb2.SpendingLimitTypeEnum.SpendingLimitType.V = (
        ...
    )
    @property
    def pending_proposal(
        self,
    ) -> global___AccountBudget.PendingAccountBudgetProposal: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: builtins.int = ...,
        billing_setup: typing.Text = ...,
        status: google.ads.google_ads.v6.proto.enums.account_budget_status_pb2.AccountBudgetStatusEnum.AccountBudgetStatus.V = ...,
        name: typing.Text = ...,
        proposed_start_date_time: typing.Text = ...,
        approved_start_date_time: typing.Text = ...,
        total_adjustments_micros: builtins.int = ...,
        amount_served_micros: builtins.int = ...,
        purchase_order_number: typing.Text = ...,
        notes: typing.Text = ...,
        pending_proposal: typing.Optional[
            global___AccountBudget.PendingAccountBudgetProposal
        ] = ...,
        proposed_end_date_time: typing.Text = ...,
        proposed_end_time_type: google.ads.google_ads.v6.proto.enums.time_type_pb2.TimeTypeEnum.TimeType.V = ...,
        approved_end_date_time: typing.Text = ...,
        approved_end_time_type: google.ads.google_ads.v6.proto.enums.time_type_pb2.TimeTypeEnum.TimeType.V = ...,
        proposed_spending_limit_micros: builtins.int = ...,
        proposed_spending_limit_type: google.ads.google_ads.v6.proto.enums.spending_limit_type_pb2.SpendingLimitTypeEnum.SpendingLimitType.V = ...,
        approved_spending_limit_micros: builtins.int = ...,
        approved_spending_limit_type: google.ads.google_ads.v6.proto.enums.spending_limit_type_pb2.SpendingLimitTypeEnum.SpendingLimitType.V = ...,
        adjusted_spending_limit_micros: builtins.int = ...,
        adjusted_spending_limit_type: google.ads.google_ads.v6.proto.enums.spending_limit_type_pb2.SpendingLimitTypeEnum.SpendingLimitType.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_approved_start_date_time",
            b"_approved_start_date_time",
            "_billing_setup",
            b"_billing_setup",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_notes",
            b"_notes",
            "_proposed_start_date_time",
            b"_proposed_start_date_time",
            "_purchase_order_number",
            b"_purchase_order_number",
            "adjusted_spending_limit",
            b"adjusted_spending_limit",
            "adjusted_spending_limit_micros",
            b"adjusted_spending_limit_micros",
            "adjusted_spending_limit_type",
            b"adjusted_spending_limit_type",
            "approved_end_date_time",
            b"approved_end_date_time",
            "approved_end_time",
            b"approved_end_time",
            "approved_end_time_type",
            b"approved_end_time_type",
            "approved_spending_limit",
            b"approved_spending_limit",
            "approved_spending_limit_micros",
            b"approved_spending_limit_micros",
            "approved_spending_limit_type",
            b"approved_spending_limit_type",
            "approved_start_date_time",
            b"approved_start_date_time",
            "billing_setup",
            b"billing_setup",
            "id",
            b"id",
            "name",
            b"name",
            "notes",
            b"notes",
            "pending_proposal",
            b"pending_proposal",
            "proposed_end_date_time",
            b"proposed_end_date_time",
            "proposed_end_time",
            b"proposed_end_time",
            "proposed_end_time_type",
            b"proposed_end_time_type",
            "proposed_spending_limit",
            b"proposed_spending_limit",
            "proposed_spending_limit_micros",
            b"proposed_spending_limit_micros",
            "proposed_spending_limit_type",
            b"proposed_spending_limit_type",
            "proposed_start_date_time",
            b"proposed_start_date_time",
            "purchase_order_number",
            b"purchase_order_number",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_approved_start_date_time",
            b"_approved_start_date_time",
            "_billing_setup",
            b"_billing_setup",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_notes",
            b"_notes",
            "_proposed_start_date_time",
            b"_proposed_start_date_time",
            "_purchase_order_number",
            b"_purchase_order_number",
            "adjusted_spending_limit",
            b"adjusted_spending_limit",
            "adjusted_spending_limit_micros",
            b"adjusted_spending_limit_micros",
            "adjusted_spending_limit_type",
            b"adjusted_spending_limit_type",
            "amount_served_micros",
            b"amount_served_micros",
            "approved_end_date_time",
            b"approved_end_date_time",
            "approved_end_time",
            b"approved_end_time",
            "approved_end_time_type",
            b"approved_end_time_type",
            "approved_spending_limit",
            b"approved_spending_limit",
            "approved_spending_limit_micros",
            b"approved_spending_limit_micros",
            "approved_spending_limit_type",
            b"approved_spending_limit_type",
            "approved_start_date_time",
            b"approved_start_date_time",
            "billing_setup",
            b"billing_setup",
            "id",
            b"id",
            "name",
            b"name",
            "notes",
            b"notes",
            "pending_proposal",
            b"pending_proposal",
            "proposed_end_date_time",
            b"proposed_end_date_time",
            "proposed_end_time",
            b"proposed_end_time",
            "proposed_end_time_type",
            b"proposed_end_time_type",
            "proposed_spending_limit",
            b"proposed_spending_limit",
            "proposed_spending_limit_micros",
            b"proposed_spending_limit_micros",
            "proposed_spending_limit_type",
            b"proposed_spending_limit_type",
            "proposed_start_date_time",
            b"proposed_start_date_time",
            "purchase_order_number",
            b"purchase_order_number",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "total_adjustments_micros",
            b"total_adjustments_micros",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_approved_start_date_time", b"_approved_start_date_time"
        ],
    ) -> typing_extensions.Literal["approved_start_date_time"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_billing_setup", b"_billing_setup"],
    ) -> typing_extensions.Literal["billing_setup"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_notes", b"_notes"]
    ) -> typing_extensions.Literal["notes"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_proposed_start_date_time", b"_proposed_start_date_time"
        ],
    ) -> typing_extensions.Literal["proposed_start_date_time"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_purchase_order_number", b"_purchase_order_number"
        ],
    ) -> typing_extensions.Literal["purchase_order_number"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "adjusted_spending_limit", b"adjusted_spending_limit"
        ],
    ) -> typing_extensions.Literal[
        "adjusted_spending_limit_micros", "adjusted_spending_limit_type"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "approved_end_time", b"approved_end_time"
        ],
    ) -> typing_extensions.Literal[
        "approved_end_date_time", "approved_end_time_type"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "approved_spending_limit", b"approved_spending_limit"
        ],
    ) -> typing_extensions.Literal[
        "approved_spending_limit_micros", "approved_spending_limit_type"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "proposed_end_time", b"proposed_end_time"
        ],
    ) -> typing_extensions.Literal[
        "proposed_end_date_time", "proposed_end_time_type"
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "proposed_spending_limit", b"proposed_spending_limit"
        ],
    ) -> typing_extensions.Literal[
        "proposed_spending_limit_micros", "proposed_spending_limit_type"
    ]: ...

global___AccountBudget = AccountBudget



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.keyword_plan_network_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class KeywordPlanCampaign(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LANGUAGE_CONSTANTS_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_NETWORK_FIELD_NUMBER: builtins.int
    CPC_BID_MICROS_FIELD_NUMBER: builtins.int
    GEO_TARGETS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    keyword_plan_network: google.ads.google_ads.v4.proto.enums.keyword_plan_network_pb2.KeywordPlanNetworkEnum.KeywordPlanNetwork.V = (
        ...
    )
    @property
    def keyword_plan(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def language_constants(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    @property
    def cpc_bid_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def geo_targets(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___KeywordPlanGeoTarget
    ]: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        keyword_plan: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        language_constants: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
        keyword_plan_network: google.ads.google_ads.v4.proto.enums.keyword_plan_network_pb2.KeywordPlanNetworkEnum.KeywordPlanNetwork.V = ...,
        cpc_bid_micros: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        geo_targets: typing.Optional[
            typing.Iterable[global___KeywordPlanGeoTarget]
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "cpc_bid_micros",
            b"cpc_bid_micros",
            "id",
            b"id",
            "keyword_plan",
            b"keyword_plan",
            "name",
            b"name",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "cpc_bid_micros",
            b"cpc_bid_micros",
            "geo_targets",
            b"geo_targets",
            "id",
            b"id",
            "keyword_plan",
            b"keyword_plan",
            "keyword_plan_network",
            b"keyword_plan_network",
            "language_constants",
            b"language_constants",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...

global___KeywordPlanCampaign = KeywordPlanCampaign

class KeywordPlanGeoTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    GEO_TARGET_CONSTANT_FIELD_NUMBER: builtins.int
    @property
    def geo_target_constant(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        geo_target_constant: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "geo_target_constant", b"geo_target_constant"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "geo_target_constant", b"geo_target_constant"
        ],
    ) -> None: ...

global___KeywordPlanGeoTarget = KeywordPlanGeoTarget



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Video(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    DURATION_MILLIS_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: typing.Text = ...
    channel_id: typing.Text = ...
    duration_millis: builtins.int = ...
    title: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: typing.Text = ...,
        channel_id: typing.Text = ...,
        duration_millis: builtins.int = ...,
        title: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_channel_id",
            b"_channel_id",
            "_duration_millis",
            b"_duration_millis",
            "_id",
            b"_id",
            "_title",
            b"_title",
            "channel_id",
            b"channel_id",
            "duration_millis",
            b"duration_millis",
            "id",
            b"id",
            "title",
            b"title",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_channel_id",
            b"_channel_id",
            "_duration_millis",
            b"_duration_millis",
            "_id",
            b"_id",
            "_title",
            b"_title",
            "channel_id",
            b"channel_id",
            "duration_millis",
            b"duration_millis",
            "id",
            b"id",
            "resource_name",
            b"resource_name",
            "title",
            b"title",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_channel_id", b"_channel_id"]
    ) -> typing_extensions.Literal["channel_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_duration_millis", b"_duration_millis"],
    ) -> typing_extensions.Literal["duration_millis"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_title", b"_title"]
    ) -> typing_extensions.Literal["title"]: ...

global___Video = Video



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DynamicSearchAdsSearchTermView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    SEARCH_TERM_FIELD_NUMBER: builtins.int
    HEADLINE_FIELD_NUMBER: builtins.int
    LANDING_PAGE_FIELD_NUMBER: builtins.int
    PAGE_URL_FIELD_NUMBER: builtins.int
    HAS_NEGATIVE_KEYWORD_FIELD_NUMBER: builtins.int
    HAS_MATCHING_KEYWORD_FIELD_NUMBER: builtins.int
    HAS_NEGATIVE_URL_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    search_term: typing.Text = ...
    headline: typing.Text = ...
    landing_page: typing.Text = ...
    page_url: typing.Text = ...
    has_negative_keyword: builtins.bool = ...
    has_matching_keyword: builtins.bool = ...
    has_negative_url: builtins.bool = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        search_term: typing.Text = ...,
        headline: typing.Text = ...,
        landing_page: typing.Text = ...,
        page_url: typing.Text = ...,
        has_negative_keyword: builtins.bool = ...,
        has_matching_keyword: builtins.bool = ...,
        has_negative_url: builtins.bool = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_has_matching_keyword",
            b"_has_matching_keyword",
            "_has_negative_keyword",
            b"_has_negative_keyword",
            "_has_negative_url",
            b"_has_negative_url",
            "_headline",
            b"_headline",
            "_landing_page",
            b"_landing_page",
            "_page_url",
            b"_page_url",
            "_search_term",
            b"_search_term",
            "has_matching_keyword",
            b"has_matching_keyword",
            "has_negative_keyword",
            b"has_negative_keyword",
            "has_negative_url",
            b"has_negative_url",
            "headline",
            b"headline",
            "landing_page",
            b"landing_page",
            "page_url",
            b"page_url",
            "search_term",
            b"search_term",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_has_matching_keyword",
            b"_has_matching_keyword",
            "_has_negative_keyword",
            b"_has_negative_keyword",
            "_has_negative_url",
            b"_has_negative_url",
            "_headline",
            b"_headline",
            "_landing_page",
            b"_landing_page",
            "_page_url",
            b"_page_url",
            "_search_term",
            b"_search_term",
            "has_matching_keyword",
            b"has_matching_keyword",
            "has_negative_keyword",
            b"has_negative_keyword",
            "has_negative_url",
            b"has_negative_url",
            "headline",
            b"headline",
            "landing_page",
            b"landing_page",
            "page_url",
            b"page_url",
            "resource_name",
            b"resource_name",
            "search_term",
            b"search_term",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_has_matching_keyword", b"_has_matching_keyword"
        ],
    ) -> typing_extensions.Literal["has_matching_keyword"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_has_negative_keyword", b"_has_negative_keyword"
        ],
    ) -> typing_extensions.Literal["has_negative_keyword"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_has_negative_url", b"_has_negative_url"
        ],
    ) -> typing_extensions.Literal["has_negative_url"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_headline", b"_headline"]
    ) -> typing_extensions.Literal["headline"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_landing_page", b"_landing_page"]
    ) -> typing_extensions.Literal["landing_page"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_page_url", b"_page_url"]
    ) -> typing_extensions.Literal["page_url"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_search_term", b"_search_term"]
    ) -> typing_extensions.Literal["search_term"]: ...

global___DynamicSearchAdsSearchTermView = DynamicSearchAdsSearchTermView



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BiddingStrategyErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _BiddingStrategyError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            BiddingStrategyError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = BiddingStrategyErrorEnum.BiddingStrategyError.V(0)
        UNKNOWN = BiddingStrategyErrorEnum.BiddingStrategyError.V(1)
        DUPLICATE_NAME = BiddingStrategyErrorEnum.BiddingStrategyError.V(2)
        CANNOT_CHANGE_BIDDING_STRATEGY_TYPE = (
            BiddingStrategyErrorEnum.BiddingStrategyError.V(3)
        )
        CANNOT_REMOVE_ASSOCIATED_STRATEGY = (
            BiddingStrategyErrorEnum.BiddingStrategyError.V(4)
        )
        BIDDING_STRATEGY_NOT_SUPPORTED = (
            BiddingStrategyErrorEnum.BiddingStrategyError.V(5)
        )
        INCOMPATIBLE_BIDDING_STRATEGY_AND_BIDDING_STRATEGY_GOAL_TYPE = (
            BiddingStrategyErrorEnum.BiddingStrategyError.V(6)
        )
    class BiddingStrategyError(metaclass=_BiddingStrategyError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = BiddingStrategyErrorEnum.BiddingStrategyError.V(0)
    UNKNOWN = BiddingStrategyErrorEnum.BiddingStrategyError.V(1)
    DUPLICATE_NAME = BiddingStrategyErrorEnum.BiddingStrategyError.V(2)
    CANNOT_CHANGE_BIDDING_STRATEGY_TYPE = (
        BiddingStrategyErrorEnum.BiddingStrategyError.V(3)
    )
    CANNOT_REMOVE_ASSOCIATED_STRATEGY = BiddingStrategyErrorEnum.BiddingStrategyError.V(
        4
    )
    BIDDING_STRATEGY_NOT_SUPPORTED = BiddingStrategyErrorEnum.BiddingStrategyError.V(5)
    INCOMPATIBLE_BIDDING_STRATEGY_AND_BIDDING_STRATEGY_GOAL_TYPE = (
        BiddingStrategyErrorEnum.BiddingStrategyError.V(6)
    )
    def __init__(
        self,
    ) -> None: ...

global___BiddingStrategyErrorEnum = BiddingStrategyErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.common.tag_snippet_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class RemarketingAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TAG_SNIPPETS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    @property
    def id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def tag_snippets(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v4.proto.common.tag_snippet_pb2.TagSnippet
    ]: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        tag_snippets: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v4.proto.common.tag_snippet_pb2.TagSnippet
            ]
        ] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["id", b"id", "name", b"name"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "id",
            b"id",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "tag_snippets",
            b"tag_snippets",
        ],
    ) -> None: ...

global___RemarketingAction = RemarketingAction



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MonthOfYearEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _MonthOfYear(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MonthOfYear.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = MonthOfYearEnum.MonthOfYear.V(0)
        UNKNOWN = MonthOfYearEnum.MonthOfYear.V(1)
        JANUARY = MonthOfYearEnum.MonthOfYear.V(2)
        FEBRUARY = MonthOfYearEnum.MonthOfYear.V(3)
        MARCH = MonthOfYearEnum.MonthOfYear.V(4)
        APRIL = MonthOfYearEnum.MonthOfYear.V(5)
        MAY = MonthOfYearEnum.MonthOfYear.V(6)
        JUNE = MonthOfYearEnum.MonthOfYear.V(7)
        JULY = MonthOfYearEnum.MonthOfYear.V(8)
        AUGUST = MonthOfYearEnum.MonthOfYear.V(9)
        SEPTEMBER = MonthOfYearEnum.MonthOfYear.V(10)
        OCTOBER = MonthOfYearEnum.MonthOfYear.V(11)
        NOVEMBER = MonthOfYearEnum.MonthOfYear.V(12)
        DECEMBER = MonthOfYearEnum.MonthOfYear.V(13)
    class MonthOfYear(metaclass=_MonthOfYear):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = MonthOfYearEnum.MonthOfYear.V(0)
    UNKNOWN = MonthOfYearEnum.MonthOfYear.V(1)
    JANUARY = MonthOfYearEnum.MonthOfYear.V(2)
    FEBRUARY = MonthOfYearEnum.MonthOfYear.V(3)
    MARCH = MonthOfYearEnum.MonthOfYear.V(4)
    APRIL = MonthOfYearEnum.MonthOfYear.V(5)
    MAY = MonthOfYearEnum.MonthOfYear.V(6)
    JUNE = MonthOfYearEnum.MonthOfYear.V(7)
    JULY = MonthOfYearEnum.MonthOfYear.V(8)
    AUGUST = MonthOfYearEnum.MonthOfYear.V(9)
    SEPTEMBER = MonthOfYearEnum.MonthOfYear.V(10)
    OCTOBER = MonthOfYearEnum.MonthOfYear.V(11)
    NOVEMBER = MonthOfYearEnum.MonthOfYear.V(12)
    DECEMBER = MonthOfYearEnum.MonthOfYear.V(13)
    def __init__(
        self,
    ) -> None: ...

global___MonthOfYearEnum = MonthOfYearEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.common.simulation_pb2
import google.ads.google_ads.v5.proto.enums.simulation_modification_method_pb2
import google.ads.google_ads.v5.proto.enums.simulation_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdGroupSimulation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    AD_GROUP_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    MODIFICATION_METHOD_FIELD_NUMBER: builtins.int
    START_DATE_FIELD_NUMBER: builtins.int
    END_DATE_FIELD_NUMBER: builtins.int
    CPC_BID_POINT_LIST_FIELD_NUMBER: builtins.int
    CPV_BID_POINT_LIST_FIELD_NUMBER: builtins.int
    TARGET_CPA_POINT_LIST_FIELD_NUMBER: builtins.int
    TARGET_ROAS_POINT_LIST_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    ad_group_id: builtins.int = ...
    type: google.ads.google_ads.v5.proto.enums.simulation_type_pb2.SimulationTypeEnum.SimulationType.V = (
        ...
    )
    modification_method: google.ads.google_ads.v5.proto.enums.simulation_modification_method_pb2.SimulationModificationMethodEnum.SimulationModificationMethod.V = (
        ...
    )
    start_date: typing.Text = ...
    end_date: typing.Text = ...
    @property
    def cpc_bid_point_list(
        self,
    ) -> google.ads.google_ads.v5.proto.common.simulation_pb2.CpcBidSimulationPointList: ...
    @property
    def cpv_bid_point_list(
        self,
    ) -> google.ads.google_ads.v5.proto.common.simulation_pb2.CpvBidSimulationPointList: ...
    @property
    def target_cpa_point_list(
        self,
    ) -> google.ads.google_ads.v5.proto.common.simulation_pb2.TargetCpaSimulationPointList: ...
    @property
    def target_roas_point_list(
        self,
    ) -> google.ads.google_ads.v5.proto.common.simulation_pb2.TargetRoasSimulationPointList: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        ad_group_id: builtins.int = ...,
        type: google.ads.google_ads.v5.proto.enums.simulation_type_pb2.SimulationTypeEnum.SimulationType.V = ...,
        modification_method: google.ads.google_ads.v5.proto.enums.simulation_modification_method_pb2.SimulationModificationMethodEnum.SimulationModificationMethod.V = ...,
        start_date: typing.Text = ...,
        end_date: typing.Text = ...,
        cpc_bid_point_list: typing.Optional[
            google.ads.google_ads.v5.proto.common.simulation_pb2.CpcBidSimulationPointList
        ] = ...,
        cpv_bid_point_list: typing.Optional[
            google.ads.google_ads.v5.proto.common.simulation_pb2.CpvBidSimulationPointList
        ] = ...,
        target_cpa_point_list: typing.Optional[
            google.ads.google_ads.v5.proto.common.simulation_pb2.TargetCpaSimulationPointList
        ] = ...,
        target_roas_point_list: typing.Optional[
            google.ads.google_ads.v5.proto.common.simulation_pb2.TargetRoasSimulationPointList
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_ad_group_id",
            b"_ad_group_id",
            "_end_date",
            b"_end_date",
            "_start_date",
            b"_start_date",
            "ad_group_id",
            b"ad_group_id",
            "cpc_bid_point_list",
            b"cpc_bid_point_list",
            "cpv_bid_point_list",
            b"cpv_bid_point_list",
            "end_date",
            b"end_date",
            "point_list",
            b"point_list",
            "start_date",
            b"start_date",
            "target_cpa_point_list",
            b"target_cpa_point_list",
            "target_roas_point_list",
            b"target_roas_point_list",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_ad_group_id",
            b"_ad_group_id",
            "_end_date",
            b"_end_date",
            "_start_date",
            b"_start_date",
            "ad_group_id",
            b"ad_group_id",
            "cpc_bid_point_list",
            b"cpc_bid_point_list",
            "cpv_bid_point_list",
            b"cpv_bid_point_list",
            "end_date",
            b"end_date",
            "modification_method",
            b"modification_method",
            "point_list",
            b"point_list",
            "resource_name",
            b"resource_name",
            "start_date",
            b"start_date",
            "target_cpa_point_list",
            b"target_cpa_point_list",
            "target_roas_point_list",
            b"target_roas_point_list",
            "type",
            b"type",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_ad_group_id", b"_ad_group_id"]
    ) -> typing_extensions.Literal["ad_group_id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_end_date", b"_end_date"]
    ) -> typing_extensions.Literal["end_date"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_start_date", b"_start_date"]
    ) -> typing_extensions.Literal["start_date"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["point_list", b"point_list"]
    ) -> typing_extensions.Literal[
        "cpc_bid_point_list",
        "cpv_bid_point_list",
        "target_cpa_point_list",
        "target_roas_point_list",
    ]: ...

global___AdGroupSimulation = AdGroupSimulation



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.operating_system_version_operator_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class OperatingSystemVersionConstant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OS_MAJOR_VERSION_FIELD_NUMBER: builtins.int
    OS_MINOR_VERSION_FIELD_NUMBER: builtins.int
    OPERATOR_TYPE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: builtins.int = ...
    name: typing.Text = ...
    os_major_version: builtins.int = ...
    os_minor_version: builtins.int = ...
    operator_type: google.ads.google_ads.v6.proto.enums.operating_system_version_operator_type_pb2.OperatingSystemVersionOperatorTypeEnum.OperatingSystemVersionOperatorType.V = (
        ...
    )
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: builtins.int = ...,
        name: typing.Text = ...,
        os_major_version: builtins.int = ...,
        os_minor_version: builtins.int = ...,
        operator_type: google.ads.google_ads.v6.proto.enums.operating_system_version_operator_type_pb2.OperatingSystemVersionOperatorTypeEnum.OperatingSystemVersionOperatorType.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_os_major_version",
            b"_os_major_version",
            "_os_minor_version",
            b"_os_minor_version",
            "id",
            b"id",
            "name",
            b"name",
            "os_major_version",
            b"os_major_version",
            "os_minor_version",
            b"os_minor_version",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_os_major_version",
            b"_os_major_version",
            "_os_minor_version",
            b"_os_minor_version",
            "id",
            b"id",
            "name",
            b"name",
            "operator_type",
            b"operator_type",
            "os_major_version",
            b"os_major_version",
            "os_minor_version",
            b"os_minor_version",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_os_major_version", b"_os_major_version"
        ],
    ) -> typing_extensions.Literal["os_major_version"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_os_minor_version", b"_os_minor_version"
        ],
    ) -> typing_extensions.Literal["os_minor_version"]: ...

global___OperatingSystemVersionConstant = OperatingSystemVersionConstant



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MobileAppCategoryConstant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    @property
    def id(self) -> google.protobuf.wrappers_pb2.Int32Value: ...
    @property
    def name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: typing.Optional[google.protobuf.wrappers_pb2.Int32Value] = ...,
        name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["id", b"id", "name", b"name"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "id", b"id", "name", b"name", "resource_name", b"resource_name"
        ],
    ) -> None: ...

global___MobileAppCategoryConstant = MobileAppCategoryConstant



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class TravelPlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _TravelPlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            TravelPlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(0)
        UNKNOWN = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(1)
        DESTINATION_ID = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(2)
        ORIGIN_ID = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(3)
        TITLE = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(4)
        DESTINATION_NAME = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(5)
        ORIGIN_NAME = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(6)
        PRICE = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(7)
        FORMATTED_PRICE = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(8)
        SALE_PRICE = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(9)
        FORMATTED_SALE_PRICE = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(10)
        IMAGE_URL = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(11)
        CATEGORY = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(12)
        CONTEXTUAL_KEYWORDS = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(13)
        DESTINATION_ADDRESS = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(14)
        FINAL_URL = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(15)
        FINAL_MOBILE_URLS = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(16)
        TRACKING_URL = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(17)
        ANDROID_APP_LINK = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(18)
        SIMILAR_DESTINATION_IDS = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(
            19
        )
        IOS_APP_LINK = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(20)
        IOS_APP_STORE_ID = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(21)
    class TravelPlaceholderField(metaclass=_TravelPlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(0)
    UNKNOWN = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(1)
    DESTINATION_ID = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(2)
    ORIGIN_ID = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(3)
    TITLE = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(4)
    DESTINATION_NAME = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(5)
    ORIGIN_NAME = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(6)
    PRICE = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(7)
    FORMATTED_PRICE = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(8)
    SALE_PRICE = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(9)
    FORMATTED_SALE_PRICE = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(10)
    IMAGE_URL = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(11)
    CATEGORY = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(12)
    CONTEXTUAL_KEYWORDS = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(13)
    DESTINATION_ADDRESS = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(14)
    FINAL_URL = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(15)
    FINAL_MOBILE_URLS = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(16)
    TRACKING_URL = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(17)
    ANDROID_APP_LINK = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(18)
    SIMILAR_DESTINATION_IDS = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(19)
    IOS_APP_LINK = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(20)
    IOS_APP_STORE_ID = TravelPlaceholderFieldEnum.TravelPlaceholderField.V(21)
    def __init__(
        self,
    ) -> None: ...

global___TravelPlaceholderFieldEnum = TravelPlaceholderFieldEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.label_pb2
import grpc

from .label_service_pb2 import *

class LabelServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetLabel(
        self,
        request: global___GetLabelRequest,
    ) -> google.ads.google_ads.v4.proto.resources.label_pb2.Label: ...
    def MutateLabels(
        self,
        request: global___MutateLabelsRequest,
    ) -> global___MutateLabelsResponse: ...

class LabelServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetLabel(
        self,
        request: global___GetLabelRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.label_pb2.Label: ...
    @abc.abstractmethod
    def MutateLabels(
        self,
        request: global___MutateLabelsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateLabelsResponse: ...

def add_LabelServiceServicer_to_server(
    servicer: LabelServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.user_interest_pb2
import grpc

from .user_interest_service_pb2 import *

class UserInterestServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetUserInterest(
        self,
        request: global___GetUserInterestRequest,
    ) -> google.ads.google_ads.v5.proto.resources.user_interest_pb2.UserInterest: ...

class UserInterestServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetUserInterest(
        self,
        request: global___GetUserInterestRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.user_interest_pb2.UserInterest: ...

def add_UserInterestServiceServicer_to_server(
    servicer: UserInterestServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BudgetTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _BudgetType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[BudgetType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = BudgetTypeEnum.BudgetType.V(0)
        UNKNOWN = BudgetTypeEnum.BudgetType.V(1)
        STANDARD = BudgetTypeEnum.BudgetType.V(2)
        HOTEL_ADS_COMMISSION = BudgetTypeEnum.BudgetType.V(3)
        FIXED_CPA = BudgetTypeEnum.BudgetType.V(4)
    class BudgetType(metaclass=_BudgetType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = BudgetTypeEnum.BudgetType.V(0)
    UNKNOWN = BudgetTypeEnum.BudgetType.V(1)
    STANDARD = BudgetTypeEnum.BudgetType.V(2)
    HOTEL_ADS_COMMISSION = BudgetTypeEnum.BudgetType.V(3)
    FIXED_CPA = BudgetTypeEnum.BudgetType.V(4)
    def __init__(
        self,
    ) -> None: ...

global___BudgetTypeEnum = BudgetTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.resources.geo_target_constant_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GetGeoTargetConstantRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___GetGeoTargetConstantRequest = GetGeoTargetConstantRequest

class SuggestGeoTargetConstantsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class LocationNames(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        NAMES_FIELD_NUMBER: builtins.int
        @property
        def names(
            self,
        ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
            google.protobuf.wrappers_pb2.StringValue
        ]: ...
        def __init__(
            self,
            *,
            names: typing.Optional[
                typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
            ] = ...,
        ) -> None: ...
        def ClearField(
            self, field_name: typing_extensions.Literal["names", b"names"]
        ) -> None: ...
    class GeoTargets(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        GEO_TARGET_CONSTANTS_FIELD_NUMBER: builtins.int
        @property
        def geo_target_constants(
            self,
        ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
            google.protobuf.wrappers_pb2.StringValue
        ]: ...
        def __init__(
            self,
            *,
            geo_target_constants: typing.Optional[
                typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
            ] = ...,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "geo_target_constants", b"geo_target_constants"
            ],
        ) -> None: ...
    LOCALE_FIELD_NUMBER: builtins.int
    COUNTRY_CODE_FIELD_NUMBER: builtins.int
    LOCATION_NAMES_FIELD_NUMBER: builtins.int
    GEO_TARGETS_FIELD_NUMBER: builtins.int
    @property
    def locale(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def country_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def location_names(
        self,
    ) -> global___SuggestGeoTargetConstantsRequest.LocationNames: ...
    @property
    def geo_targets(self) -> global___SuggestGeoTargetConstantsRequest.GeoTargets: ...
    def __init__(
        self,
        *,
        locale: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        country_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        location_names: typing.Optional[
            global___SuggestGeoTargetConstantsRequest.LocationNames
        ] = ...,
        geo_targets: typing.Optional[
            global___SuggestGeoTargetConstantsRequest.GeoTargets
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "country_code",
            b"country_code",
            "geo_targets",
            b"geo_targets",
            "locale",
            b"locale",
            "location_names",
            b"location_names",
            "query",
            b"query",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "country_code",
            b"country_code",
            "geo_targets",
            b"geo_targets",
            "locale",
            b"locale",
            "location_names",
            b"location_names",
            "query",
            b"query",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["query", b"query"]
    ) -> typing_extensions.Literal["location_names", "geo_targets"]: ...

global___SuggestGeoTargetConstantsRequest = SuggestGeoTargetConstantsRequest

class SuggestGeoTargetConstantsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    GEO_TARGET_CONSTANT_SUGGESTIONS_FIELD_NUMBER: builtins.int
    @property
    def geo_target_constant_suggestions(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___GeoTargetConstantSuggestion
    ]: ...
    def __init__(
        self,
        *,
        geo_target_constant_suggestions: typing.Optional[
            typing.Iterable[global___GeoTargetConstantSuggestion]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "geo_target_constant_suggestions", b"geo_target_constant_suggestions"
        ],
    ) -> None: ...

global___SuggestGeoTargetConstantsResponse = SuggestGeoTargetConstantsResponse

class GeoTargetConstantSuggestion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LOCALE_FIELD_NUMBER: builtins.int
    REACH_FIELD_NUMBER: builtins.int
    SEARCH_TERM_FIELD_NUMBER: builtins.int
    GEO_TARGET_CONSTANT_FIELD_NUMBER: builtins.int
    GEO_TARGET_CONSTANT_PARENTS_FIELD_NUMBER: builtins.int
    @property
    def locale(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def reach(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def search_term(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def geo_target_constant(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.geo_target_constant_pb2.GeoTargetConstant: ...
    @property
    def geo_target_constant_parents(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v4.proto.resources.geo_target_constant_pb2.GeoTargetConstant
    ]: ...
    def __init__(
        self,
        *,
        locale: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        reach: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        search_term: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        geo_target_constant: typing.Optional[
            google.ads.google_ads.v4.proto.resources.geo_target_constant_pb2.GeoTargetConstant
        ] = ...,
        geo_target_constant_parents: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v4.proto.resources.geo_target_constant_pb2.GeoTargetConstant
            ]
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "geo_target_constant",
            b"geo_target_constant",
            "locale",
            b"locale",
            "reach",
            b"reach",
            "search_term",
            b"search_term",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "geo_target_constant",
            b"geo_target_constant",
            "geo_target_constant_parents",
            b"geo_target_constant_parents",
            "locale",
            b"locale",
            "reach",
            b"reach",
            "search_term",
            b"search_term",
        ],
    ) -> None: ...

global___GeoTargetConstantSuggestion = GeoTargetConstantSuggestion



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.feed_item_target_pb2
import grpc

from .feed_item_target_service_pb2 import *

class FeedItemTargetServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetFeedItemTarget(
        self,
        request: global___GetFeedItemTargetRequest,
    ) -> google.ads.google_ads.v4.proto.resources.feed_item_target_pb2.FeedItemTarget: ...
    def MutateFeedItemTargets(
        self,
        request: global___MutateFeedItemTargetsRequest,
    ) -> global___MutateFeedItemTargetsResponse: ...

class FeedItemTargetServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetFeedItemTarget(
        self,
        request: global___GetFeedItemTargetRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.feed_item_target_pb2.FeedItemTarget: ...
    @abc.abstractmethod
    def MutateFeedItemTargets(
        self,
        request: global___MutateFeedItemTargetsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateFeedItemTargetsResponse: ...

def add_FeedItemTargetServiceServicer_to_server(
    servicer: FeedItemTargetServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.customer_pay_per_conversion_eligibility_failure_reason_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Customer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    DESCRIPTIVE_NAME_FIELD_NUMBER: builtins.int
    CURRENCY_CODE_FIELD_NUMBER: builtins.int
    TIME_ZONE_FIELD_NUMBER: builtins.int
    TRACKING_URL_TEMPLATE_FIELD_NUMBER: builtins.int
    FINAL_URL_SUFFIX_FIELD_NUMBER: builtins.int
    AUTO_TAGGING_ENABLED_FIELD_NUMBER: builtins.int
    HAS_PARTNERS_BADGE_FIELD_NUMBER: builtins.int
    MANAGER_FIELD_NUMBER: builtins.int
    TEST_ACCOUNT_FIELD_NUMBER: builtins.int
    CALL_REPORTING_SETTING_FIELD_NUMBER: builtins.int
    CONVERSION_TRACKING_SETTING_FIELD_NUMBER: builtins.int
    REMARKETING_SETTING_FIELD_NUMBER: builtins.int
    PAY_PER_CONVERSION_ELIGIBILITY_FAILURE_REASONS_FIELD_NUMBER: builtins.int
    OPTIMIZATION_SCORE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: builtins.int = ...
    descriptive_name: typing.Text = ...
    currency_code: typing.Text = ...
    time_zone: typing.Text = ...
    tracking_url_template: typing.Text = ...
    final_url_suffix: typing.Text = ...
    auto_tagging_enabled: builtins.bool = ...
    has_partners_badge: builtins.bool = ...
    manager: builtins.bool = ...
    test_account: builtins.bool = ...
    pay_per_conversion_eligibility_failure_reasons: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        google.ads.google_ads.v5.proto.enums.customer_pay_per_conversion_eligibility_failure_reason_pb2.CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V
    ] = ...
    optimization_score: builtins.float = ...
    @property
    def call_reporting_setting(self) -> global___CallReportingSetting: ...
    @property
    def conversion_tracking_setting(self) -> global___ConversionTrackingSetting: ...
    @property
    def remarketing_setting(self) -> global___RemarketingSetting: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: builtins.int = ...,
        descriptive_name: typing.Text = ...,
        currency_code: typing.Text = ...,
        time_zone: typing.Text = ...,
        tracking_url_template: typing.Text = ...,
        final_url_suffix: typing.Text = ...,
        auto_tagging_enabled: builtins.bool = ...,
        has_partners_badge: builtins.bool = ...,
        manager: builtins.bool = ...,
        test_account: builtins.bool = ...,
        call_reporting_setting: typing.Optional[global___CallReportingSetting] = ...,
        conversion_tracking_setting: typing.Optional[
            global___ConversionTrackingSetting
        ] = ...,
        remarketing_setting: typing.Optional[global___RemarketingSetting] = ...,
        pay_per_conversion_eligibility_failure_reasons: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v5.proto.enums.customer_pay_per_conversion_eligibility_failure_reason_pb2.CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason.V
            ]
        ] = ...,
        optimization_score: builtins.float = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_auto_tagging_enabled",
            b"_auto_tagging_enabled",
            "_currency_code",
            b"_currency_code",
            "_descriptive_name",
            b"_descriptive_name",
            "_final_url_suffix",
            b"_final_url_suffix",
            "_has_partners_badge",
            b"_has_partners_badge",
            "_id",
            b"_id",
            "_manager",
            b"_manager",
            "_optimization_score",
            b"_optimization_score",
            "_test_account",
            b"_test_account",
            "_time_zone",
            b"_time_zone",
            "_tracking_url_template",
            b"_tracking_url_template",
            "auto_tagging_enabled",
            b"auto_tagging_enabled",
            "call_reporting_setting",
            b"call_reporting_setting",
            "conversion_tracking_setting",
            b"conversion_tracking_setting",
            "currency_code",
            b"currency_code",
            "descriptive_name",
            b"descriptive_name",
            "final_url_suffix",
            b"final_url_suffix",
            "has_partners_badge",
            b"has_partners_badge",
            "id",
            b"id",
            "manager",
            b"manager",
            "optimization_score",
            b"optimization_score",
            "remarketing_setting",
            b"remarketing_setting",
            "test_account",
            b"test_account",
            "time_zone",
            b"time_zone",
            "tracking_url_template",
            b"tracking_url_template",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_auto_tagging_enabled",
            b"_auto_tagging_enabled",
            "_currency_code",
            b"_currency_code",
            "_descriptive_name",
            b"_descriptive_name",
            "_final_url_suffix",
            b"_final_url_suffix",
            "_has_partners_badge",
            b"_has_partners_badge",
            "_id",
            b"_id",
            "_manager",
            b"_manager",
            "_optimization_score",
            b"_optimization_score",
            "_test_account",
            b"_test_account",
            "_time_zone",
            b"_time_zone",
            "_tracking_url_template",
            b"_tracking_url_template",
            "auto_tagging_enabled",
            b"auto_tagging_enabled",
            "call_reporting_setting",
            b"call_reporting_setting",
            "conversion_tracking_setting",
            b"conversion_tracking_setting",
            "currency_code",
            b"currency_code",
            "descriptive_name",
            b"descriptive_name",
            "final_url_suffix",
            b"final_url_suffix",
            "has_partners_badge",
            b"has_partners_badge",
            "id",
            b"id",
            "manager",
            b"manager",
            "optimization_score",
            b"optimization_score",
            "pay_per_conversion_eligibility_failure_reasons",
            b"pay_per_conversion_eligibility_failure_reasons",
            "remarketing_setting",
            b"remarketing_setting",
            "resource_name",
            b"resource_name",
            "test_account",
            b"test_account",
            "time_zone",
            b"time_zone",
            "tracking_url_template",
            b"tracking_url_template",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_auto_tagging_enabled", b"_auto_tagging_enabled"
        ],
    ) -> typing_extensions.Literal["auto_tagging_enabled"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_currency_code", b"_currency_code"],
    ) -> typing_extensions.Literal["currency_code"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_descriptive_name", b"_descriptive_name"
        ],
    ) -> typing_extensions.Literal["descriptive_name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_final_url_suffix", b"_final_url_suffix"
        ],
    ) -> typing_extensions.Literal["final_url_suffix"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_has_partners_badge", b"_has_partners_badge"
        ],
    ) -> typing_extensions.Literal["has_partners_badge"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_manager", b"_manager"]
    ) -> typing_extensions.Literal["manager"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_optimization_score", b"_optimization_score"
        ],
    ) -> typing_extensions.Literal["optimization_score"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_test_account", b"_test_account"]
    ) -> typing_extensions.Literal["test_account"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_time_zone", b"_time_zone"]
    ) -> typing_extensions.Literal["time_zone"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_tracking_url_template", b"_tracking_url_template"
        ],
    ) -> typing_extensions.Literal["tracking_url_template"]: ...

global___Customer = Customer

class CallReportingSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CALL_REPORTING_ENABLED_FIELD_NUMBER: builtins.int
    CALL_CONVERSION_REPORTING_ENABLED_FIELD_NUMBER: builtins.int
    CALL_CONVERSION_ACTION_FIELD_NUMBER: builtins.int
    call_reporting_enabled: builtins.bool = ...
    call_conversion_reporting_enabled: builtins.bool = ...
    call_conversion_action: typing.Text = ...
    def __init__(
        self,
        *,
        call_reporting_enabled: builtins.bool = ...,
        call_conversion_reporting_enabled: builtins.bool = ...,
        call_conversion_action: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_call_conversion_action",
            b"_call_conversion_action",
            "_call_conversion_reporting_enabled",
            b"_call_conversion_reporting_enabled",
            "_call_reporting_enabled",
            b"_call_reporting_enabled",
            "call_conversion_action",
            b"call_conversion_action",
            "call_conversion_reporting_enabled",
            b"call_conversion_reporting_enabled",
            "call_reporting_enabled",
            b"call_reporting_enabled",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_call_conversion_action",
            b"_call_conversion_action",
            "_call_conversion_reporting_enabled",
            b"_call_conversion_reporting_enabled",
            "_call_reporting_enabled",
            b"_call_reporting_enabled",
            "call_conversion_action",
            b"call_conversion_action",
            "call_conversion_reporting_enabled",
            b"call_conversion_reporting_enabled",
            "call_reporting_enabled",
            b"call_reporting_enabled",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_call_conversion_action", b"_call_conversion_action"
        ],
    ) -> typing_extensions.Literal["call_conversion_action"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_call_conversion_reporting_enabled", b"_call_conversion_reporting_enabled"
        ],
    ) -> typing_extensions.Literal["call_conversion_reporting_enabled"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_call_reporting_enabled", b"_call_reporting_enabled"
        ],
    ) -> typing_extensions.Literal["call_reporting_enabled"]: ...

global___CallReportingSetting = CallReportingSetting

class ConversionTrackingSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONVERSION_TRACKING_ID_FIELD_NUMBER: builtins.int
    CROSS_ACCOUNT_CONVERSION_TRACKING_ID_FIELD_NUMBER: builtins.int
    conversion_tracking_id: builtins.int = ...
    cross_account_conversion_tracking_id: builtins.int = ...
    def __init__(
        self,
        *,
        conversion_tracking_id: builtins.int = ...,
        cross_account_conversion_tracking_id: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_conversion_tracking_id",
            b"_conversion_tracking_id",
            "_cross_account_conversion_tracking_id",
            b"_cross_account_conversion_tracking_id",
            "conversion_tracking_id",
            b"conversion_tracking_id",
            "cross_account_conversion_tracking_id",
            b"cross_account_conversion_tracking_id",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_conversion_tracking_id",
            b"_conversion_tracking_id",
            "_cross_account_conversion_tracking_id",
            b"_cross_account_conversion_tracking_id",
            "conversion_tracking_id",
            b"conversion_tracking_id",
            "cross_account_conversion_tracking_id",
            b"cross_account_conversion_tracking_id",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversion_tracking_id", b"_conversion_tracking_id"
        ],
    ) -> typing_extensions.Literal["conversion_tracking_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_cross_account_conversion_tracking_id",
            b"_cross_account_conversion_tracking_id",
        ],
    ) -> typing_extensions.Literal["cross_account_conversion_tracking_id"]: ...

global___ConversionTrackingSetting = ConversionTrackingSetting

class RemarketingSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    GOOGLE_GLOBAL_SITE_TAG_FIELD_NUMBER: builtins.int
    google_global_site_tag: typing.Text = ...
    def __init__(
        self,
        *,
        google_global_site_tag: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_google_global_site_tag",
            b"_google_global_site_tag",
            "google_global_site_tag",
            b"google_global_site_tag",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_google_global_site_tag",
            b"_google_global_site_tag",
            "google_global_site_tag",
            b"google_global_site_tag",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_google_global_site_tag", b"_google_global_site_tag"
        ],
    ) -> typing_extensions.Literal["google_global_site_tag"]: ...

global___RemarketingSetting = RemarketingSetting



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.geo_targeting_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GeographicView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    LOCATION_TYPE_FIELD_NUMBER: builtins.int
    COUNTRY_CRITERION_ID_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    location_type: google.ads.google_ads.v4.proto.enums.geo_targeting_type_pb2.GeoTargetingTypeEnum.GeoTargetingType.V = (
        ...
    )
    @property
    def country_criterion_id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        location_type: google.ads.google_ads.v4.proto.enums.geo_targeting_type_pb2.GeoTargetingTypeEnum.GeoTargetingType.V = ...,
        country_criterion_id: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "country_criterion_id", b"country_criterion_id"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "country_criterion_id",
            b"country_criterion_id",
            "location_type",
            b"location_type",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...

global___GeographicView = GeographicView



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.common.ad_type_infos_pb2
import google.ads.google_ads.v4.proto.common.custom_parameter_pb2
import google.ads.google_ads.v4.proto.common.final_app_url_pb2
import google.ads.google_ads.v4.proto.common.url_collection_pb2
import google.ads.google_ads.v4.proto.enums.ad_type_pb2
import google.ads.google_ads.v4.proto.enums.device_pb2
import google.ads.google_ads.v4.proto.enums.system_managed_entity_source_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Ad(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    FINAL_URLS_FIELD_NUMBER: builtins.int
    FINAL_APP_URLS_FIELD_NUMBER: builtins.int
    FINAL_MOBILE_URLS_FIELD_NUMBER: builtins.int
    TRACKING_URL_TEMPLATE_FIELD_NUMBER: builtins.int
    FINAL_URL_SUFFIX_FIELD_NUMBER: builtins.int
    URL_CUSTOM_PARAMETERS_FIELD_NUMBER: builtins.int
    DISPLAY_URL_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    ADDED_BY_GOOGLE_ADS_FIELD_NUMBER: builtins.int
    DEVICE_PREFERENCE_FIELD_NUMBER: builtins.int
    URL_COLLECTIONS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SYSTEM_MANAGED_RESOURCE_SOURCE_FIELD_NUMBER: builtins.int
    TEXT_AD_FIELD_NUMBER: builtins.int
    EXPANDED_TEXT_AD_FIELD_NUMBER: builtins.int
    CALL_ONLY_AD_FIELD_NUMBER: builtins.int
    EXPANDED_DYNAMIC_SEARCH_AD_FIELD_NUMBER: builtins.int
    HOTEL_AD_FIELD_NUMBER: builtins.int
    SHOPPING_SMART_AD_FIELD_NUMBER: builtins.int
    SHOPPING_PRODUCT_AD_FIELD_NUMBER: builtins.int
    GMAIL_AD_FIELD_NUMBER: builtins.int
    IMAGE_AD_FIELD_NUMBER: builtins.int
    VIDEO_AD_FIELD_NUMBER: builtins.int
    RESPONSIVE_SEARCH_AD_FIELD_NUMBER: builtins.int
    LEGACY_RESPONSIVE_DISPLAY_AD_FIELD_NUMBER: builtins.int
    APP_AD_FIELD_NUMBER: builtins.int
    LEGACY_APP_INSTALL_AD_FIELD_NUMBER: builtins.int
    RESPONSIVE_DISPLAY_AD_FIELD_NUMBER: builtins.int
    LOCAL_AD_FIELD_NUMBER: builtins.int
    DISPLAY_UPLOAD_AD_FIELD_NUMBER: builtins.int
    APP_ENGAGEMENT_AD_FIELD_NUMBER: builtins.int
    SHOPPING_COMPARISON_LISTING_AD_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    type: google.ads.google_ads.v4.proto.enums.ad_type_pb2.AdTypeEnum.AdType.V = ...
    device_preference: google.ads.google_ads.v4.proto.enums.device_pb2.DeviceEnum.Device.V = (
        ...
    )
    system_managed_resource_source: google.ads.google_ads.v4.proto.enums.system_managed_entity_source_pb2.SystemManagedResourceSourceEnum.SystemManagedResourceSource.V = (
        ...
    )
    @property
    def id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def final_urls(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    @property
    def final_app_urls(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v4.proto.common.final_app_url_pb2.FinalAppUrl
    ]: ...
    @property
    def final_mobile_urls(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.protobuf.wrappers_pb2.StringValue
    ]: ...
    @property
    def tracking_url_template(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def final_url_suffix(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def url_custom_parameters(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v4.proto.common.custom_parameter_pb2.CustomParameter
    ]: ...
    @property
    def display_url(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def added_by_google_ads(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def url_collections(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v4.proto.common.url_collection_pb2.UrlCollection
    ]: ...
    @property
    def name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def text_ad(
        self,
    ) -> google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.TextAdInfo: ...
    @property
    def expanded_text_ad(
        self,
    ) -> google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.ExpandedTextAdInfo: ...
    @property
    def call_only_ad(
        self,
    ) -> google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.CallOnlyAdInfo: ...
    @property
    def expanded_dynamic_search_ad(
        self,
    ) -> google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.ExpandedDynamicSearchAdInfo: ...
    @property
    def hotel_ad(
        self,
    ) -> google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.HotelAdInfo: ...
    @property
    def shopping_smart_ad(
        self,
    ) -> google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.ShoppingSmartAdInfo: ...
    @property
    def shopping_product_ad(
        self,
    ) -> google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.ShoppingProductAdInfo: ...
    @property
    def gmail_ad(
        self,
    ) -> google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.GmailAdInfo: ...
    @property
    def image_ad(
        self,
    ) -> google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.ImageAdInfo: ...
    @property
    def video_ad(
        self,
    ) -> google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.VideoAdInfo: ...
    @property
    def responsive_search_ad(
        self,
    ) -> google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.ResponsiveSearchAdInfo: ...
    @property
    def legacy_responsive_display_ad(
        self,
    ) -> google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.LegacyResponsiveDisplayAdInfo: ...
    @property
    def app_ad(
        self,
    ) -> google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.AppAdInfo: ...
    @property
    def legacy_app_install_ad(
        self,
    ) -> google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.LegacyAppInstallAdInfo: ...
    @property
    def responsive_display_ad(
        self,
    ) -> google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.ResponsiveDisplayAdInfo: ...
    @property
    def local_ad(
        self,
    ) -> google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.LocalAdInfo: ...
    @property
    def display_upload_ad(
        self,
    ) -> google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.DisplayUploadAdInfo: ...
    @property
    def app_engagement_ad(
        self,
    ) -> google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.AppEngagementAdInfo: ...
    @property
    def shopping_comparison_listing_ad(
        self,
    ) -> google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.ShoppingComparisonListingAdInfo: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        final_urls: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
        final_app_urls: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v4.proto.common.final_app_url_pb2.FinalAppUrl
            ]
        ] = ...,
        final_mobile_urls: typing.Optional[
            typing.Iterable[google.protobuf.wrappers_pb2.StringValue]
        ] = ...,
        tracking_url_template: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        final_url_suffix: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        url_custom_parameters: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v4.proto.common.custom_parameter_pb2.CustomParameter
            ]
        ] = ...,
        display_url: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        type: google.ads.google_ads.v4.proto.enums.ad_type_pb2.AdTypeEnum.AdType.V = ...,
        added_by_google_ads: typing.Optional[
            google.protobuf.wrappers_pb2.BoolValue
        ] = ...,
        device_preference: google.ads.google_ads.v4.proto.enums.device_pb2.DeviceEnum.Device.V = ...,
        url_collections: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v4.proto.common.url_collection_pb2.UrlCollection
            ]
        ] = ...,
        name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        system_managed_resource_source: google.ads.google_ads.v4.proto.enums.system_managed_entity_source_pb2.SystemManagedResourceSourceEnum.SystemManagedResourceSource.V = ...,
        text_ad: typing.Optional[
            google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.TextAdInfo
        ] = ...,
        expanded_text_ad: typing.Optional[
            google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.ExpandedTextAdInfo
        ] = ...,
        call_only_ad: typing.Optional[
            google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.CallOnlyAdInfo
        ] = ...,
        expanded_dynamic_search_ad: typing.Optional[
            google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.ExpandedDynamicSearchAdInfo
        ] = ...,
        hotel_ad: typing.Optional[
            google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.HotelAdInfo
        ] = ...,
        shopping_smart_ad: typing.Optional[
            google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.ShoppingSmartAdInfo
        ] = ...,
        shopping_product_ad: typing.Optional[
            google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.ShoppingProductAdInfo
        ] = ...,
        gmail_ad: typing.Optional[
            google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.GmailAdInfo
        ] = ...,
        image_ad: typing.Optional[
            google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.ImageAdInfo
        ] = ...,
        video_ad: typing.Optional[
            google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.VideoAdInfo
        ] = ...,
        responsive_search_ad: typing.Optional[
            google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.ResponsiveSearchAdInfo
        ] = ...,
        legacy_responsive_display_ad: typing.Optional[
            google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.LegacyResponsiveDisplayAdInfo
        ] = ...,
        app_ad: typing.Optional[
            google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.AppAdInfo
        ] = ...,
        legacy_app_install_ad: typing.Optional[
            google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.LegacyAppInstallAdInfo
        ] = ...,
        responsive_display_ad: typing.Optional[
            google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.ResponsiveDisplayAdInfo
        ] = ...,
        local_ad: typing.Optional[
            google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.LocalAdInfo
        ] = ...,
        display_upload_ad: typing.Optional[
            google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.DisplayUploadAdInfo
        ] = ...,
        app_engagement_ad: typing.Optional[
            google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.AppEngagementAdInfo
        ] = ...,
        shopping_comparison_listing_ad: typing.Optional[
            google.ads.google_ads.v4.proto.common.ad_type_infos_pb2.ShoppingComparisonListingAdInfo
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "ad_data",
            b"ad_data",
            "added_by_google_ads",
            b"added_by_google_ads",
            "app_ad",
            b"app_ad",
            "app_engagement_ad",
            b"app_engagement_ad",
            "call_only_ad",
            b"call_only_ad",
            "display_upload_ad",
            b"display_upload_ad",
            "display_url",
            b"display_url",
            "expanded_dynamic_search_ad",
            b"expanded_dynamic_search_ad",
            "expanded_text_ad",
            b"expanded_text_ad",
            "final_url_suffix",
            b"final_url_suffix",
            "gmail_ad",
            b"gmail_ad",
            "hotel_ad",
            b"hotel_ad",
            "id",
            b"id",
            "image_ad",
            b"image_ad",
            "legacy_app_install_ad",
            b"legacy_app_install_ad",
            "legacy_responsive_display_ad",
            b"legacy_responsive_display_ad",
            "local_ad",
            b"local_ad",
            "name",
            b"name",
            "responsive_display_ad",
            b"responsive_display_ad",
            "responsive_search_ad",
            b"responsive_search_ad",
            "shopping_comparison_listing_ad",
            b"shopping_comparison_listing_ad",
            "shopping_product_ad",
            b"shopping_product_ad",
            "shopping_smart_ad",
            b"shopping_smart_ad",
            "text_ad",
            b"text_ad",
            "tracking_url_template",
            b"tracking_url_template",
            "video_ad",
            b"video_ad",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "ad_data",
            b"ad_data",
            "added_by_google_ads",
            b"added_by_google_ads",
            "app_ad",
            b"app_ad",
            "app_engagement_ad",
            b"app_engagement_ad",
            "call_only_ad",
            b"call_only_ad",
            "device_preference",
            b"device_preference",
            "display_upload_ad",
            b"display_upload_ad",
            "display_url",
            b"display_url",
            "expanded_dynamic_search_ad",
            b"expanded_dynamic_search_ad",
            "expanded_text_ad",
            b"expanded_text_ad",
            "final_app_urls",
            b"final_app_urls",
            "final_mobile_urls",
            b"final_mobile_urls",
            "final_url_suffix",
            b"final_url_suffix",
            "final_urls",
            b"final_urls",
            "gmail_ad",
            b"gmail_ad",
            "hotel_ad",
            b"hotel_ad",
            "id",
            b"id",
            "image_ad",
            b"image_ad",
            "legacy_app_install_ad",
            b"legacy_app_install_ad",
            "legacy_responsive_display_ad",
            b"legacy_responsive_display_ad",
            "local_ad",
            b"local_ad",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "responsive_display_ad",
            b"responsive_display_ad",
            "responsive_search_ad",
            b"responsive_search_ad",
            "shopping_comparison_listing_ad",
            b"shopping_comparison_listing_ad",
            "shopping_product_ad",
            b"shopping_product_ad",
            "shopping_smart_ad",
            b"shopping_smart_ad",
            "system_managed_resource_source",
            b"system_managed_resource_source",
            "text_ad",
            b"text_ad",
            "tracking_url_template",
            b"tracking_url_template",
            "type",
            b"type",
            "url_collections",
            b"url_collections",
            "url_custom_parameters",
            b"url_custom_parameters",
            "video_ad",
            b"video_ad",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["ad_data", b"ad_data"]
    ) -> typing_extensions.Literal[
        "text_ad",
        "expanded_text_ad",
        "call_only_ad",
        "expanded_dynamic_search_ad",
        "hotel_ad",
        "shopping_smart_ad",
        "shopping_product_ad",
        "gmail_ad",
        "image_ad",
        "video_ad",
        "responsive_search_ad",
        "legacy_responsive_display_ad",
        "app_ad",
        "legacy_app_install_ad",
        "responsive_display_ad",
        "local_ad",
        "display_upload_ad",
        "app_engagement_ad",
        "shopping_comparison_listing_ad",
    ]: ...

global___Ad = Ad



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.user_list_pb2
import grpc

from .user_list_service_pb2 import *

class UserListServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetUserList(
        self,
        request: global___GetUserListRequest,
    ) -> google.ads.google_ads.v5.proto.resources.user_list_pb2.UserList: ...
    def MutateUserLists(
        self,
        request: global___MutateUserListsRequest,
    ) -> global___MutateUserListsResponse: ...

class UserListServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetUserList(
        self,
        request: global___GetUserListRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.user_list_pb2.UserList: ...
    @abc.abstractmethod
    def MutateUserLists(
        self,
        request: global___MutateUserListsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateUserListsResponse: ...

def add_UserListServiceServicer_to_server(
    servicer: UserListServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class UserListSizeRangeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _UserListSizeRange(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            UserListSizeRange.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = UserListSizeRangeEnum.UserListSizeRange.V(0)
        UNKNOWN = UserListSizeRangeEnum.UserListSizeRange.V(1)
        LESS_THAN_FIVE_HUNDRED = UserListSizeRangeEnum.UserListSizeRange.V(2)
        LESS_THAN_ONE_THOUSAND = UserListSizeRangeEnum.UserListSizeRange.V(3)
        ONE_THOUSAND_TO_TEN_THOUSAND = UserListSizeRangeEnum.UserListSizeRange.V(4)
        TEN_THOUSAND_TO_FIFTY_THOUSAND = UserListSizeRangeEnum.UserListSizeRange.V(5)
        FIFTY_THOUSAND_TO_ONE_HUNDRED_THOUSAND = (
            UserListSizeRangeEnum.UserListSizeRange.V(6)
        )
        ONE_HUNDRED_THOUSAND_TO_THREE_HUNDRED_THOUSAND = (
            UserListSizeRangeEnum.UserListSizeRange.V(7)
        )
        THREE_HUNDRED_THOUSAND_TO_FIVE_HUNDRED_THOUSAND = (
            UserListSizeRangeEnum.UserListSizeRange.V(8)
        )
        FIVE_HUNDRED_THOUSAND_TO_ONE_MILLION = (
            UserListSizeRangeEnum.UserListSizeRange.V(9)
        )
        ONE_MILLION_TO_TWO_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(10)
        TWO_MILLION_TO_THREE_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(11)
        THREE_MILLION_TO_FIVE_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(12)
        FIVE_MILLION_TO_TEN_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(13)
        TEN_MILLION_TO_TWENTY_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(14)
        TWENTY_MILLION_TO_THIRTY_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(15)
        THIRTY_MILLION_TO_FIFTY_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(16)
        OVER_FIFTY_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(17)
    class UserListSizeRange(metaclass=_UserListSizeRange):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = UserListSizeRangeEnum.UserListSizeRange.V(0)
    UNKNOWN = UserListSizeRangeEnum.UserListSizeRange.V(1)
    LESS_THAN_FIVE_HUNDRED = UserListSizeRangeEnum.UserListSizeRange.V(2)
    LESS_THAN_ONE_THOUSAND = UserListSizeRangeEnum.UserListSizeRange.V(3)
    ONE_THOUSAND_TO_TEN_THOUSAND = UserListSizeRangeEnum.UserListSizeRange.V(4)
    TEN_THOUSAND_TO_FIFTY_THOUSAND = UserListSizeRangeEnum.UserListSizeRange.V(5)
    FIFTY_THOUSAND_TO_ONE_HUNDRED_THOUSAND = UserListSizeRangeEnum.UserListSizeRange.V(
        6
    )
    ONE_HUNDRED_THOUSAND_TO_THREE_HUNDRED_THOUSAND = (
        UserListSizeRangeEnum.UserListSizeRange.V(7)
    )
    THREE_HUNDRED_THOUSAND_TO_FIVE_HUNDRED_THOUSAND = (
        UserListSizeRangeEnum.UserListSizeRange.V(8)
    )
    FIVE_HUNDRED_THOUSAND_TO_ONE_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(9)
    ONE_MILLION_TO_TWO_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(10)
    TWO_MILLION_TO_THREE_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(11)
    THREE_MILLION_TO_FIVE_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(12)
    FIVE_MILLION_TO_TEN_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(13)
    TEN_MILLION_TO_TWENTY_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(14)
    TWENTY_MILLION_TO_THIRTY_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(15)
    THIRTY_MILLION_TO_FIFTY_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(16)
    OVER_FIFTY_MILLION = UserListSizeRangeEnum.UserListSizeRange.V(17)
    def __init__(
        self,
    ) -> None: ...

global___UserListSizeRangeEnum = UserListSizeRangeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BudgetDeliveryMethodEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _BudgetDeliveryMethod(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            BudgetDeliveryMethod.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = BudgetDeliveryMethodEnum.BudgetDeliveryMethod.V(0)
        UNKNOWN = BudgetDeliveryMethodEnum.BudgetDeliveryMethod.V(1)
        STANDARD = BudgetDeliveryMethodEnum.BudgetDeliveryMethod.V(2)
        ACCELERATED = BudgetDeliveryMethodEnum.BudgetDeliveryMethod.V(3)
    class BudgetDeliveryMethod(metaclass=_BudgetDeliveryMethod):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = BudgetDeliveryMethodEnum.BudgetDeliveryMethod.V(0)
    UNKNOWN = BudgetDeliveryMethodEnum.BudgetDeliveryMethod.V(1)
    STANDARD = BudgetDeliveryMethodEnum.BudgetDeliveryMethod.V(2)
    ACCELERATED = BudgetDeliveryMethodEnum.BudgetDeliveryMethod.V(3)
    def __init__(
        self,
    ) -> None: ...

global___BudgetDeliveryMethodEnum = BudgetDeliveryMethodEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdCustomizerErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdCustomizerError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AdCustomizerError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdCustomizerErrorEnum.AdCustomizerError.V(0)
        UNKNOWN = AdCustomizerErrorEnum.AdCustomizerError.V(1)
        COUNTDOWN_INVALID_DATE_FORMAT = AdCustomizerErrorEnum.AdCustomizerError.V(2)
        COUNTDOWN_DATE_IN_PAST = AdCustomizerErrorEnum.AdCustomizerError.V(3)
        COUNTDOWN_INVALID_LOCALE = AdCustomizerErrorEnum.AdCustomizerError.V(4)
        COUNTDOWN_INVALID_START_DAYS_BEFORE = AdCustomizerErrorEnum.AdCustomizerError.V(
            5
        )
        UNKNOWN_USER_LIST = AdCustomizerErrorEnum.AdCustomizerError.V(6)
    class AdCustomizerError(metaclass=_AdCustomizerError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdCustomizerErrorEnum.AdCustomizerError.V(0)
    UNKNOWN = AdCustomizerErrorEnum.AdCustomizerError.V(1)
    COUNTDOWN_INVALID_DATE_FORMAT = AdCustomizerErrorEnum.AdCustomizerError.V(2)
    COUNTDOWN_DATE_IN_PAST = AdCustomizerErrorEnum.AdCustomizerError.V(3)
    COUNTDOWN_INVALID_LOCALE = AdCustomizerErrorEnum.AdCustomizerError.V(4)
    COUNTDOWN_INVALID_START_DAYS_BEFORE = AdCustomizerErrorEnum.AdCustomizerError.V(5)
    UNKNOWN_USER_LIST = AdCustomizerErrorEnum.AdCustomizerError.V(6)
    def __init__(
        self,
    ) -> None: ...

global___AdCustomizerErrorEnum = AdCustomizerErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AccessReasonEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AccessReason(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AccessReason.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AccessReasonEnum.AccessReason.V(0)
        UNKNOWN = AccessReasonEnum.AccessReason.V(1)
        OWNED = AccessReasonEnum.AccessReason.V(2)
        SHARED = AccessReasonEnum.AccessReason.V(3)
        LICENSED = AccessReasonEnum.AccessReason.V(4)
        SUBSCRIBED = AccessReasonEnum.AccessReason.V(5)
        AFFILIATED = AccessReasonEnum.AccessReason.V(6)
    class AccessReason(metaclass=_AccessReason):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AccessReasonEnum.AccessReason.V(0)
    UNKNOWN = AccessReasonEnum.AccessReason.V(1)
    OWNED = AccessReasonEnum.AccessReason.V(2)
    SHARED = AccessReasonEnum.AccessReason.V(3)
    LICENSED = AccessReasonEnum.AccessReason.V(4)
    SUBSCRIBED = AccessReasonEnum.AccessReason.V(5)
    AFFILIATED = AccessReasonEnum.AccessReason.V(6)
    def __init__(
        self,
    ) -> None: ...

global___AccessReasonEnum = AccessReasonEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MatchingFunctionContextTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _MatchingFunctionContextType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            MatchingFunctionContextType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = MatchingFunctionContextTypeEnum.MatchingFunctionContextType.V(0)
        UNKNOWN = MatchingFunctionContextTypeEnum.MatchingFunctionContextType.V(1)
        FEED_ITEM_ID = MatchingFunctionContextTypeEnum.MatchingFunctionContextType.V(2)
        DEVICE_NAME = MatchingFunctionContextTypeEnum.MatchingFunctionContextType.V(3)
    class MatchingFunctionContextType(metaclass=_MatchingFunctionContextType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = MatchingFunctionContextTypeEnum.MatchingFunctionContextType.V(0)
    UNKNOWN = MatchingFunctionContextTypeEnum.MatchingFunctionContextType.V(1)
    FEED_ITEM_ID = MatchingFunctionContextTypeEnum.MatchingFunctionContextType.V(2)
    DEVICE_NAME = MatchingFunctionContextTypeEnum.MatchingFunctionContextType.V(3)
    def __init__(
        self,
    ) -> None: ...

global___MatchingFunctionContextTypeEnum = MatchingFunctionContextTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.media_file_pb2
import grpc

from .media_file_service_pb2 import *

class MediaFileServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetMediaFile(
        self,
        request: global___GetMediaFileRequest,
    ) -> google.ads.google_ads.v4.proto.resources.media_file_pb2.MediaFile: ...
    def MutateMediaFiles(
        self,
        request: global___MutateMediaFilesRequest,
    ) -> global___MutateMediaFilesResponse: ...

class MediaFileServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetMediaFile(
        self,
        request: global___GetMediaFileRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.media_file_pb2.MediaFile: ...
    @abc.abstractmethod
    def MutateMediaFiles(
        self,
        request: global___MutateMediaFilesRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateMediaFilesResponse: ...

def add_MediaFileServiceServicer_to_server(
    servicer: MediaFileServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DynamicSearchAdsSearchTermView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    SEARCH_TERM_FIELD_NUMBER: builtins.int
    HEADLINE_FIELD_NUMBER: builtins.int
    LANDING_PAGE_FIELD_NUMBER: builtins.int
    PAGE_URL_FIELD_NUMBER: builtins.int
    HAS_NEGATIVE_KEYWORD_FIELD_NUMBER: builtins.int
    HAS_MATCHING_KEYWORD_FIELD_NUMBER: builtins.int
    HAS_NEGATIVE_URL_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    @property
    def search_term(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def headline(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def landing_page(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def page_url(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def has_negative_keyword(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def has_matching_keyword(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def has_negative_url(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        search_term: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        headline: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        landing_page: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        page_url: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        has_negative_keyword: typing.Optional[
            google.protobuf.wrappers_pb2.BoolValue
        ] = ...,
        has_matching_keyword: typing.Optional[
            google.protobuf.wrappers_pb2.BoolValue
        ] = ...,
        has_negative_url: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "has_matching_keyword",
            b"has_matching_keyword",
            "has_negative_keyword",
            b"has_negative_keyword",
            "has_negative_url",
            b"has_negative_url",
            "headline",
            b"headline",
            "landing_page",
            b"landing_page",
            "page_url",
            b"page_url",
            "search_term",
            b"search_term",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "has_matching_keyword",
            b"has_matching_keyword",
            "has_negative_keyword",
            b"has_negative_keyword",
            "has_negative_url",
            b"has_negative_url",
            "headline",
            b"headline",
            "landing_page",
            b"landing_page",
            "page_url",
            b"page_url",
            "resource_name",
            b"resource_name",
            "search_term",
            b"search_term",
        ],
    ) -> None: ...

global___DynamicSearchAdsSearchTermView = DynamicSearchAdsSearchTermView



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.feed_item_set_string_filter_type_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DynamicLocationSetFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LABELS_FIELD_NUMBER: builtins.int
    BUSINESS_NAME_FILTER_FIELD_NUMBER: builtins.int
    labels: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        typing.Text
    ] = ...
    @property
    def business_name_filter(self) -> global___BusinessNameFilter: ...
    def __init__(
        self,
        *,
        labels: typing.Optional[typing.Iterable[typing.Text]] = ...,
        business_name_filter: typing.Optional[global___BusinessNameFilter] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "business_name_filter", b"business_name_filter"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "business_name_filter", b"business_name_filter", "labels", b"labels"
        ],
    ) -> None: ...

global___DynamicLocationSetFilter = DynamicLocationSetFilter

class BusinessNameFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BUSINESS_NAME_FIELD_NUMBER: builtins.int
    FILTER_TYPE_FIELD_NUMBER: builtins.int
    business_name: typing.Text = ...
    filter_type: google.ads.google_ads.v6.proto.enums.feed_item_set_string_filter_type_pb2.FeedItemSetStringFilterTypeEnum.FeedItemSetStringFilterType.V = (
        ...
    )
    def __init__(
        self,
        *,
        business_name: typing.Text = ...,
        filter_type: google.ads.google_ads.v6.proto.enums.feed_item_set_string_filter_type_pb2.FeedItemSetStringFilterTypeEnum.FeedItemSetStringFilterType.V = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "business_name", b"business_name", "filter_type", b"filter_type"
        ],
    ) -> None: ...

global___BusinessNameFilter = BusinessNameFilter

class DynamicAffiliateLocationSetFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CHAIN_IDS_FIELD_NUMBER: builtins.int
    chain_ids: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        builtins.int
    ] = ...
    def __init__(
        self,
        *,
        chain_ids: typing.Optional[typing.Iterable[builtins.int]] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["chain_ids", b"chain_ids"]
    ) -> None: ...

global___DynamicAffiliateLocationSetFilter = DynamicAffiliateLocationSetFilter



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BiddingErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _BiddingError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[BiddingError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = BiddingErrorEnum.BiddingError.V(0)
        UNKNOWN = BiddingErrorEnum.BiddingError.V(1)
        BIDDING_STRATEGY_TRANSITION_NOT_ALLOWED = BiddingErrorEnum.BiddingError.V(2)
        CANNOT_ATTACH_BIDDING_STRATEGY_TO_CAMPAIGN = BiddingErrorEnum.BiddingError.V(7)
        INVALID_ANONYMOUS_BIDDING_STRATEGY_TYPE = BiddingErrorEnum.BiddingError.V(10)
        INVALID_BIDDING_STRATEGY_TYPE = BiddingErrorEnum.BiddingError.V(14)
        INVALID_BID = BiddingErrorEnum.BiddingError.V(17)
        BIDDING_STRATEGY_NOT_AVAILABLE_FOR_ACCOUNT_TYPE = (
            BiddingErrorEnum.BiddingError.V(18)
        )
        CONVERSION_TRACKING_NOT_ENABLED = BiddingErrorEnum.BiddingError.V(19)
        NOT_ENOUGH_CONVERSIONS = BiddingErrorEnum.BiddingError.V(20)
        CANNOT_CREATE_CAMPAIGN_WITH_BIDDING_STRATEGY = BiddingErrorEnum.BiddingError.V(
            21
        )
        CANNOT_TARGET_CONTENT_NETWORK_ONLY_WITH_CAMPAIGN_LEVEL_POP_BIDDING_STRATEGY = (
            BiddingErrorEnum.BiddingError.V(23)
        )
        BIDDING_STRATEGY_NOT_SUPPORTED_WITH_AD_SCHEDULE = (
            BiddingErrorEnum.BiddingError.V(24)
        )
        PAY_PER_CONVERSION_NOT_AVAILABLE_FOR_CUSTOMER = BiddingErrorEnum.BiddingError.V(
            25
        )
        PAY_PER_CONVERSION_NOT_ALLOWED_WITH_TARGET_CPA = (
            BiddingErrorEnum.BiddingError.V(26)
        )
        BIDDING_STRATEGY_NOT_ALLOWED_FOR_SEARCH_ONLY_CAMPAIGNS = (
            BiddingErrorEnum.BiddingError.V(27)
        )
        BIDDING_STRATEGY_NOT_SUPPORTED_IN_DRAFTS_OR_EXPERIMENTS = (
            BiddingErrorEnum.BiddingError.V(28)
        )
        BIDDING_STRATEGY_TYPE_DOES_NOT_SUPPORT_PRODUCT_TYPE_ADGROUP_CRITERION = (
            BiddingErrorEnum.BiddingError.V(29)
        )
        BID_TOO_SMALL = BiddingErrorEnum.BiddingError.V(30)
        BID_TOO_BIG = BiddingErrorEnum.BiddingError.V(31)
        BID_TOO_MANY_FRACTIONAL_DIGITS = BiddingErrorEnum.BiddingError.V(32)
        INVALID_DOMAIN_NAME = BiddingErrorEnum.BiddingError.V(33)
        NOT_COMPATIBLE_WITH_PAYMENT_MODE = BiddingErrorEnum.BiddingError.V(34)
        NOT_COMPATIBLE_WITH_BUDGET_TYPE = BiddingErrorEnum.BiddingError.V(35)
        NOT_COMPATIBLE_WITH_BIDDING_STRATEGY_TYPE = BiddingErrorEnum.BiddingError.V(36)
        BIDDING_STRATEGY_TYPE_INCOMPATIBLE_WITH_SHARED_BUDGET = (
            BiddingErrorEnum.BiddingError.V(37)
        )
    class BiddingError(metaclass=_BiddingError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = BiddingErrorEnum.BiddingError.V(0)
    UNKNOWN = BiddingErrorEnum.BiddingError.V(1)
    BIDDING_STRATEGY_TRANSITION_NOT_ALLOWED = BiddingErrorEnum.BiddingError.V(2)
    CANNOT_ATTACH_BIDDING_STRATEGY_TO_CAMPAIGN = BiddingErrorEnum.BiddingError.V(7)
    INVALID_ANONYMOUS_BIDDING_STRATEGY_TYPE = BiddingErrorEnum.BiddingError.V(10)
    INVALID_BIDDING_STRATEGY_TYPE = BiddingErrorEnum.BiddingError.V(14)
    INVALID_BID = BiddingErrorEnum.BiddingError.V(17)
    BIDDING_STRATEGY_NOT_AVAILABLE_FOR_ACCOUNT_TYPE = BiddingErrorEnum.BiddingError.V(
        18
    )
    CONVERSION_TRACKING_NOT_ENABLED = BiddingErrorEnum.BiddingError.V(19)
    NOT_ENOUGH_CONVERSIONS = BiddingErrorEnum.BiddingError.V(20)
    CANNOT_CREATE_CAMPAIGN_WITH_BIDDING_STRATEGY = BiddingErrorEnum.BiddingError.V(21)
    CANNOT_TARGET_CONTENT_NETWORK_ONLY_WITH_CAMPAIGN_LEVEL_POP_BIDDING_STRATEGY = (
        BiddingErrorEnum.BiddingError.V(23)
    )
    BIDDING_STRATEGY_NOT_SUPPORTED_WITH_AD_SCHEDULE = BiddingErrorEnum.BiddingError.V(
        24
    )
    PAY_PER_CONVERSION_NOT_AVAILABLE_FOR_CUSTOMER = BiddingErrorEnum.BiddingError.V(25)
    PAY_PER_CONVERSION_NOT_ALLOWED_WITH_TARGET_CPA = BiddingErrorEnum.BiddingError.V(26)
    BIDDING_STRATEGY_NOT_ALLOWED_FOR_SEARCH_ONLY_CAMPAIGNS = (
        BiddingErrorEnum.BiddingError.V(27)
    )
    BIDDING_STRATEGY_NOT_SUPPORTED_IN_DRAFTS_OR_EXPERIMENTS = (
        BiddingErrorEnum.BiddingError.V(28)
    )
    BIDDING_STRATEGY_TYPE_DOES_NOT_SUPPORT_PRODUCT_TYPE_ADGROUP_CRITERION = (
        BiddingErrorEnum.BiddingError.V(29)
    )
    BID_TOO_SMALL = BiddingErrorEnum.BiddingError.V(30)
    BID_TOO_BIG = BiddingErrorEnum.BiddingError.V(31)
    BID_TOO_MANY_FRACTIONAL_DIGITS = BiddingErrorEnum.BiddingError.V(32)
    INVALID_DOMAIN_NAME = BiddingErrorEnum.BiddingError.V(33)
    NOT_COMPATIBLE_WITH_PAYMENT_MODE = BiddingErrorEnum.BiddingError.V(34)
    NOT_COMPATIBLE_WITH_BUDGET_TYPE = BiddingErrorEnum.BiddingError.V(35)
    NOT_COMPATIBLE_WITH_BIDDING_STRATEGY_TYPE = BiddingErrorEnum.BiddingError.V(36)
    BIDDING_STRATEGY_TYPE_INCOMPATIBLE_WITH_SHARED_BUDGET = (
        BiddingErrorEnum.BiddingError.V(37)
    )
    def __init__(
        self,
    ) -> None: ...

global___BiddingErrorEnum = BiddingErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.custom_interest_member_type_pb2
import google.ads.google_ads.v6.proto.enums.custom_interest_status_pb2
import google.ads.google_ads.v6.proto.enums.custom_interest_type_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomInterest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: builtins.int = ...
    status: google.ads.google_ads.v6.proto.enums.custom_interest_status_pb2.CustomInterestStatusEnum.CustomInterestStatus.V = (
        ...
    )
    name: typing.Text = ...
    type: google.ads.google_ads.v6.proto.enums.custom_interest_type_pb2.CustomInterestTypeEnum.CustomInterestType.V = (
        ...
    )
    description: typing.Text = ...
    @property
    def members(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___CustomInterestMember
    ]: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: builtins.int = ...,
        status: google.ads.google_ads.v6.proto.enums.custom_interest_status_pb2.CustomInterestStatusEnum.CustomInterestStatus.V = ...,
        name: typing.Text = ...,
        type: google.ads.google_ads.v6.proto.enums.custom_interest_type_pb2.CustomInterestTypeEnum.CustomInterestType.V = ...,
        description: typing.Text = ...,
        members: typing.Optional[typing.Iterable[global___CustomInterestMember]] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_description",
            b"_description",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "description",
            b"description",
            "id",
            b"id",
            "name",
            b"name",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_description",
            b"_description",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "description",
            b"description",
            "id",
            b"id",
            "members",
            b"members",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "type",
            b"type",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description", b"_description"]
    ) -> typing_extensions.Literal["description"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...

global___CustomInterest = CustomInterest

class CustomInterestMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MEMBER_TYPE_FIELD_NUMBER: builtins.int
    PARAMETER_FIELD_NUMBER: builtins.int
    member_type: google.ads.google_ads.v6.proto.enums.custom_interest_member_type_pb2.CustomInterestMemberTypeEnum.CustomInterestMemberType.V = (
        ...
    )
    parameter: typing.Text = ...
    def __init__(
        self,
        *,
        member_type: google.ads.google_ads.v6.proto.enums.custom_interest_member_type_pb2.CustomInterestMemberTypeEnum.CustomInterestMemberType.V = ...,
        parameter: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_parameter", b"_parameter", "parameter", b"parameter"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_parameter",
            b"_parameter",
            "member_type",
            b"member_type",
            "parameter",
            b"parameter",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_parameter", b"_parameter"]
    ) -> typing_extensions.Literal["parameter"]: ...

global___CustomInterestMember = CustomInterestMember



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FieldErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FieldError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[FieldError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FieldErrorEnum.FieldError.V(0)
        UNKNOWN = FieldErrorEnum.FieldError.V(1)
        REQUIRED = FieldErrorEnum.FieldError.V(2)
        IMMUTABLE_FIELD = FieldErrorEnum.FieldError.V(3)
        INVALID_VALUE = FieldErrorEnum.FieldError.V(4)
        VALUE_MUST_BE_UNSET = FieldErrorEnum.FieldError.V(5)
        REQUIRED_NONEMPTY_LIST = FieldErrorEnum.FieldError.V(6)
        FIELD_CANNOT_BE_CLEARED = FieldErrorEnum.FieldError.V(7)
        BLOCKED_VALUE = FieldErrorEnum.FieldError.V(9)
    class FieldError(metaclass=_FieldError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FieldErrorEnum.FieldError.V(0)
    UNKNOWN = FieldErrorEnum.FieldError.V(1)
    REQUIRED = FieldErrorEnum.FieldError.V(2)
    IMMUTABLE_FIELD = FieldErrorEnum.FieldError.V(3)
    INVALID_VALUE = FieldErrorEnum.FieldError.V(4)
    VALUE_MUST_BE_UNSET = FieldErrorEnum.FieldError.V(5)
    REQUIRED_NONEMPTY_LIST = FieldErrorEnum.FieldError.V(6)
    FIELD_CANNOT_BE_CLEARED = FieldErrorEnum.FieldError.V(7)
    BLOCKED_VALUE = FieldErrorEnum.FieldError.V(9)
    def __init__(
        self,
    ) -> None: ...

global___FieldErrorEnum = FieldErrorEnum
